<?php



/**
 * Nupeye Mobile Payments Gateway.
 *
 * Provides a Nupeye Mobile Payments Payment Gateway.
 *
 * @class       WC_Gateway_Payleo
 * @extends     WC_Payment_Gateway
 * @version     2.1.0
 * @package     WooCommerce/Classes/Payment
 */
class WC_Gateway_Payleo extends WC_Payment_Gateway {

	/**
	 * Constructor for the gateway.
	 */
	public function __construct() {
		// Setup general properties.
		$this->setup_properties();

		// Load the settings.
		$this->init_form_fields();
		$this->init_settings();
		

		// Get settings.
		$this->title              = $this->get_option( 'title' );
		$this->description        = $this->get_option( 'description' );
		$this->api_key            = $this->get_option( 'api_key' );
		$this->widget_id          = $this->get_option( 'widget_id' );
		$this->instructions       = $this->get_option( 'instructions' );
		$this->enable_for_methods = $this->get_option( 'enable_for_methods', array() );
		$this->enable_for_virtual = $this->get_option( 'enable_for_virtual', 'yes' ) === 'yes';
		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
		add_action( 'woocommerce_thankyou_' . $this->id, array( $this, 'thankyou_page' ) );
		add_filter( 'woocommerce_payment_complete_order_status', array( $this, 'change_payment_complete_order_status' ), 10, 3 );
     //  add_action( 'wp_head', 'my_ajax_without_file' );
       // add_action( 'wp_footer', 'opbc_load_scripts' );


		// Customer Emails.
		add_action( 'woocommerce_email_before_order_table', array( $this, 'email_instructions' ), 10, 3 );
	}


  		 
	
	/**
	 * Setup general properties for the gateway.
	 */
	protected function setup_properties() {
		$this->id                 = 'payleo';
		$this->icon               = apply_filters( 'woocommerce_payleo_icon', plugins_url('../assets/grouplogo.png', __FILE__ ) );
		$this->method_title       = __( 'Nupeye Mobile Payments', 'nupeye-payments-woo' );
		$this->api_key            = __( 'Add API Key', 'nupeye-payments-woo' );
		$this->widget_id          = __( 'Add Widget ID', 'nupeye-payments-woo' );
		$this->method_description = __( 'Have your customers pay with Nupeye Mobile Payments.', 'nupeye-payments-woo' );
		$this->has_fields         = false;
	}
		
	/**
	 * Initialise Gateway Settings Form Fields.
	 */
	public function init_form_fields() {
		$this->form_fields = array(
			'enabled'            => array(
				'title'       => __( 'Enable/Disable', 'nupeye-payments-woo' ),
				'label'       => __( 'Enable Nupeye Payments', 'nupeye-payments-woo' ),
				'type'        => 'checkbox',
				'description' => '',
				'default'     => 'no',
			),
			'title'              => array(
				'title'       => __( 'Title', 'nupeye-payments-woo' ),
				'type'        => 'text',
				'description' => __( 'Nupeye Payment method description that the customer will see on your checkout.', 'nupeye-payments-woo' ),
				'default'     => __( 'Nupeye Payments', 'nupeye-payments-woo' ),
				'desc_tip'    => true,
			),
			'api_key'             => array(
				'title'       => __( 'API Key', 'nupeye-payments-woo' ),
				'type'        => 'text',
				'description' => __( 'Add your API key', 'nupeye-payments-woo' ),
				'desc_tip'    => true,
			),
			'widget_id'           => array(
				'title'       => __( 'Widget ID', 'nupeye-payments-woo' ),
				'type'        => 'text',
				'description' => __( 'Add your Widget key', 'nupeye-payments-woo' ),
				'desc_tip'    => true,
			),
			'description'        => array(
				'title'       => __( 'Description', 'nupeye-payments-woo' ),
				'type'        => 'textarea',
				'description' => __( 'Nupeye Payment method description that the customer will see on your website.', 'nupeye-payments-woo' ),
				'default'     => __( 'Nupeye Payments before delivery.', 'nupeye-payments-woo' ),
				'desc_tip'    => true,
			),
			'instructions'       => array(
				'title'       => __( 'Instructions', 'nupeye-payments-woo' ),
				'type'        => 'textarea',
				'description' => __( 'Instructions that will be added to the thank you page.', 'nupeye-payments-woo' ),
				'default'     => __( 'Nupeye Payments before delivery.', 'nupeye-payments-woo' ),
				'desc_tip'    => true,
			),
			// 'enable_for_methods' => array(
			// 	'title'             => __( 'Enable for shipping methods', 'nupeye-payments-woo' ),
			// 	'type'              => 'multiselect',
			// 	'class'             => 'wc-enhanced-select',
			// 	'css'               => 'width: 400px;',
			// 	'default'           => '',
			// 	'description'       => __( 'If payleo is only available for certain methods, set it up here. Leave blank to enable for all methods.', 'nupeye-payments-woo' ),
			// 	'options'           => $this->load_shipping_method_options(),
			// 	'desc_tip'          => true,
			// 	'custom_attributes' => array(
			// 		'data-placeholder' => __( 'Select shipping methods', 'nupeye-payments-woo' ),
			// 	),
			// ),
			// 'enable_for_virtual' => array(
			// 	'title'   => __( 'Accept for virtual orders', 'nupeye-payments-woo' ),
			// 	'label'   => __( 'Accept payleo if the order is virtual', 'nupeye-payments-woo' ),
			// 	'type'    => 'checkbox',
			// 	'default' => 'yes',
			// ),
		);
	}

	/**
	 * Check If The Gateway Is Available For Use.
	 *
	 * @return bool
	 */
	public function is_available() {
		$order          = null;
		$needs_shipping = false;

		// Test if shipping is needed first.
		if ( WC()->cart && WC()->cart->needs_shipping() ) {
			$needs_shipping = true;
		} elseif ( is_page( wc_get_page_id( 'checkout' ) ) && 0 < get_query_var( 'order-pay' ) ) {
			$order_id = absint( get_query_var( 'order-pay' ) );
			$order    = wc_get_order( $order_id );

			// Test if order needs shipping.
			if ( 0 < count( $order->get_items() ) ) {
				foreach ( $order->get_items() as $item ) {
					$_product = $item->get_product();
					if ( $_product && $_product->needs_shipping() ) {
						$needs_shipping = true;
						break;
					}
				}
			}
		}

		///$needs_shipping = apply_filters( 'woocommerce_cart_needs_shipping', $needs_shipping );

		// Virtual order, with virtual disabled.
		//if ( ! $this->enable_for_virtual && ! $needs_shipping ) {
		//	return false;
		//}

		// Only apply if all packages are being shipped via chosen method, or order is virtual.
		// if ( ! empty( $this->enable_for_methods ) && $needs_shipping ) {
		// 	$order_shipping_items            = is_object( $order ) ? $order->get_shipping_methods() : false;
		// 	$chosen_shipping_methods_session = WC()->session->get( 'chosen_shipping_methods' );

		// 	if ( $order_shipping_items ) {
		// 		$canonical_rate_ids = $this->get_canonical_order_shipping_item_rate_ids( $order_shipping_items );
		// 	} else {
		// 		$canonical_rate_ids = $this->get_canonical_package_rate_ids( $chosen_shipping_methods_session );
		// 	}

		// 	// if ( ! count( $this->get_matching_rates( $canonical_rate_ids ) ) ) {
		// 	// 	return false;
		// 	// }
		// }

		return parent::is_available();
	}

	/**
	 * Checks to see whether or not the admin settings are being accessed by the current request.
	 *
	 * @return bool
	 */
	 
	
	private function is_accessing_settings() {
		if ( is_admin() ) {
			// phpcs:disable WordPress.Security.NonceVerification
			if ( ! isset( $_REQUEST['page'] ) || 'wc-settings' !== $_REQUEST['page'] ) {
				return false;
			}
			if ( ! isset( $_REQUEST['tab'] ) || 'checkout' !== $_REQUEST['tab'] ) {
				return false;
			}
			if ( ! isset( $_REQUEST['section'] ) || 'payleo' !== $_REQUEST['section'] ) {
				return false;
			}
			// phpcs:enable WordPress.Security.NonceVerification

			return true;
		}

		return false;
	}
// function opbc_load_scripts() {
// 	wp_enqueue_style( 'style', plugins_url('/style.css', __FILE__) );
//   //  wp_enqueue_script('custom-script', plugins_url('/custom-script.js',  __FILE__), array('jquery'));
	

//  }




  




	 function my_custom_public_page()
      {
            if(isset($_GET['room_type'])){      
                  $dir = plugin_dir_path( __FILE__ );
            include($dir."custom_page.php");
           
            }
      }
	
	public function process_payment( $order_id ) {

		
		$order = wc_get_order( $order_id );

		if ( $order->get_total() > 0 ) {
		    
		  //  	$order->payment_complete();

				// // Remove cart.
				// WC()->cart->empty_cart();

				// // Return thankyou redirect.
				// return array(
				// 	'result'   => 'success',
				// 	'redirect' => $this->get_return_url( $order ),
				// );
			$this->payleo_payment_processing( $order );
		}
	}

	private function payleo_payment_processing( $order ) {
		$total = intval( $order->get_total() );
		//var_dump($total);
$total = intval( $order->get_total() );
//$total = '1';

		$phone = esc_attr( $_POST['payment_number'] );
		$password = esc_attr( $_POST['payment_password'] );
		$otpphone = esc_attr( $_POST['payment_otp'] );


		
	
			



		$network_id = '1'; // mtn
		$reason = 'Test';
		$curl = curl_init();

		curl_setopt_array($curl, array(
		  CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/auth/login',
		  CURLOPT_RETURNTRANSFER => true,
		  CURLOPT_ENCODING => '',
		  CURLOPT_MAXREDIRS => 10,
		  CURLOPT_TIMEOUT => 0,
		  CURLOPT_FOLLOWLOCATION => true,
		  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
		  CURLOPT_CUSTOMREQUEST => 'POST',
		  CURLOPT_POSTFIELDS => array('user_name' => 'Woocommerce','authentication_key' => '8aa0f7a2-1767-40c2-9911-36875c47017c'),
		 // CURLOPT_POSTFIELDS => array('user_name' => $this->widget_id,'authentication_key' => $this->api_key),
		  CURLOPT_HTTPHEADER => array(
			//'x-api-key: 8aa0f7a2-1767-40c2-9911-36875c47017c',
			'x-api-key: ' . $this->api_key
		  ),
		));
		
		$response = json_decode(curl_exec($curl));
		curl_close($curl);
		
		//curl_close($curl);
		//echo $response;
		//$url = 'https://e.patasente.com/phantom-api/pay-with-patasente/' . $this->api_key . '/' . $this->widget_id . '?phone=' . $phone . '&amount=' . $total . '&mobile_money_company_id=' . $network_id . '&reason=' . 'Payment for Order: ' .$order_id;

		//var_dump($curl);
			$tokenupdate; 

			$refreshtoken = $response->refresh_token;

		if($response->status==200){

			$tokenupdate = $response->refresh_token;
			// Remove cart.
			//WC()->cart->empty_cart();
			//update_post_meta($order_id, 'invoice_number', esc_html(sanitize_text_field($response->invoice_no)));
		//	$orderNote = __("Bykea Cash invoice is successfully created. Invoice number is <a href='https://invoice.bykea.cash/receive/invoice/".$response->invoice_no."' target='_blank'>".$response->invoice_no."</a>");
		//	$order->add_order_note( $orderNote );
			// Redirect to Bykea Cash redirect.
			if (!empty($_POST['payment_otp'])){


				$curltconf = curl_init();

				curl_setopt_array($curltconf, array(
				CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/recharge_account',
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_ENCODING => '',
				CURLOPT_MAXREDIRS => 10,
				CURLOPT_TIMEOUT => 0,
				CURLOPT_FOLLOWLOCATION => true,
				CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
				CURLOPT_CUSTOMREQUEST => 'POST',
				//CURLOPT_POSTFIELDS => array('app_id' => 'Woocommerce','authentication_key' => '8aa0f7a2-1767-40c2-9911-36875c47017c','mobile_no' => '14077905640','amount' => '1','user_name' => '14077905640','user_password' => '4321','otp' => '7650'),
				CURLOPT_POSTFIELDS => array('app_id' =>  $this->widget_id,'authentication_key' => $this->api_key,'mobile_no' =>$phone,'amount' => $total,'user_name' => $phone,'user_password' => $password,'otp' => $otpphone),

				CURLOPT_HTTPHEADER => array(
					'Content-Type: application/x-www-form-urlencoded',
					'x-api-key: 8aa0f7a2-1767-40c2-9911-36875c47017c',
					'authentication-token: eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpYXQiOjE2NDM5ODgzMTgsImV4cCI6MTY0NDAwNjMxOCwiaWQiOiIyNiIsInVzZXJuYW1lIjoiV29vY29tbWVyY2UifQ.0uyXF6Rdl_lGoge36KaIObMVh0RL9syGibO9Zk9iODE',
					'Cookie: ci_session=6jn7n3no9s2lts2mph80m5l8s2f277pd'
				),
				));


				$responseconf = json_decode(curl_exec($curlconf));
							curl_close($curlconf);
					wc_add_notice( $responseconf->message, 'error' );

					if ( $responseconf->status==200 ) {
					//	$response_body = wp_remote_retrieve_body( $responseconf );
					//	var_dump($response_body['message']);
						if ( 'Success' === $responseconf->message ) {
							$order->payment_complete();
			
							// Remove cart.
							WC()->cart->empty_cart();
			
							// Return thankyou redirect.
							return array(
								'result'   => 'success',
								'redirect' => $this->get_return_url( $order ),
							);
						}
					}


			}
			else {

			$curlotp = curl_init();

			curl_setopt_array($curlotp, array(
			  CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/send_otp',
			  CURLOPT_RETURNTRANSFER => true,
			  CURLOPT_ENCODING => '',
			  CURLOPT_MAXREDIRS => 10,
			  CURLOPT_TIMEOUT => 0,
			  CURLOPT_FOLLOWLOCATION => true,
			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			  CURLOPT_CUSTOMREQUEST => 'POST',
			  CURLOPT_POSTFIELDS => array('app_id' =>  $this->widget_id,'authentication_key' => $this->api_key,'mobile_no' => $phone,'amount' => $total,'user_name' => $phone,'user_password' => $password),
			//  CURLOPT_POSTFIELDS => array('app_id' => 'Woocommerce','authentication_key' => '8aa0f7a2-1767-40c2-9911-36875c47017c','mobile_no' => $phone,'amount' => '1','user_name' =>  $phone,'user_password' =>  $password),
			  CURLOPT_HTTPHEADER => array(
			//	'Content-Type: application/x-www-form-urlencoded',
				'x-api-key: ' . $this->api_key,
				'authentication-token: ' . $response->refresh_token
				//'Cookie: ci_session=o4bv10dmvtdf1fpbokpbm3g8bknlt1u0'
			  ),
			));
			

		//	$responseotp = curl_exec($curlotp);
			$responseotp = json_decode(curl_exec($curlotp));
			curl_close($curlotp);
			
			

			if($responseotp->status==true){
				// Remove cart.

				wc_add_notice( $responseotp->message, 'error' );
			
				
			}
			else{ 

	
			wc_add_notice( $responseotp->status, 'error' );
			
		   
			}
		}


			// return array(
			// 	'result'   => 'success',
			// 	'redirect' => "google.com.pk",
			// );
		}

		if($response->status==401)
		{
			$curlref = curl_init();

			curl_setopt_array($curlref, array(
			CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/auth/refresh_authentication',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_ENCODING => '',
			CURLOPT_MAXREDIRS => 10,
			CURLOPT_TIMEOUT => 0,
			CURLOPT_FOLLOWLOCATION => true,
			CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			CURLOPT_CUSTOMREQUEST => 'POST',
			CURLOPT_POSTFIELDS => array('user_name' => $this->widget_id,'refresh_token' =>  $response->authentication_token,'authentication_key' =>  $this->api_key),
			CURLOPT_HTTPHEADER => array(
				'authentication-token: ' . $refreshtoken
				),
			));
			$responseref = json_decode(curl_exec($curlref));
			//$responseref = curl_exec($curlref);
			
			curl_close($curlref);
		//	echo $responseref;
			$tokenupdate = $responseref->refresh_token;

			wc_add_notice( $responseref->message, 'error' );
			if (!empty($_POST['payment_otp'])){


				$curltconf = curl_init();
				
				curl_setopt_array($curltconf, array(
				  CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/recharge_account',
				  CURLOPT_RETURNTRANSFER => true,
				  CURLOPT_ENCODING => '',
				  CURLOPT_MAXREDIRS => 10,
				  CURLOPT_TIMEOUT => 0,
				  CURLOPT_FOLLOWLOCATION => true,
				  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
				  CURLOPT_CUSTOMREQUEST => 'POST',
				  //CURLOPT_POSTFIELDS => array('app_id' => 'Woocommerce','authentication_key' => '8aa0f7a2-1767-40c2-9911-36875c47017c','mobile_no' => '14077905640','amount' => '1','user_name' => '14077905640','user_password' => '4321','otp' => '7650'),
				  CURLOPT_POSTFIELDS => array('app_id' =>  $this->widget_id,'authentication_key' => $this->api_key,'mobile_no' =>$phone,'amount' => $total,'user_name' => $phone,'user_password' => $password,'otp' => $otpphone),
				
				  CURLOPT_HTTPHEADER => array(
					'Content-Type: application/x-www-form-urlencoded',
					'x-api-key: 8aa0f7a2-1767-40c2-9911-36875c47017c',
					'authentication-token: eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpYXQiOjE2NDM5ODgzMTgsImV4cCI6MTY0NDAwNjMxOCwiaWQiOiIyNiIsInVzZXJuYW1lIjoiV29vY29tbWVyY2UifQ.0uyXF6Rdl_lGoge36KaIObMVh0RL9syGibO9Zk9iODE'
					//'Cookie: ci_session=6jn7n3no9s2lts2mph80m5l8s2f277pd'
				  ),
				));
				
				
				$responseconf = json_decode(curl_exec($curlconf));
							curl_close($curlconf);
							
							wc_add_notice( $responseconf->message, 'error' );

				
							}

							else {

			$curlotp = curl_init();

			curl_setopt_array($curlotp, array(
			  CURLOPT_URL => 'https://nupeye.com/recharge_services/v2/send_otp',
			  CURLOPT_RETURNTRANSFER => true,
			  CURLOPT_ENCODING => '',
			  CURLOPT_MAXREDIRS => 10,
			  CURLOPT_TIMEOUT => 0,
			  CURLOPT_FOLLOWLOCATION => true,
			  CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
			  CURLOPT_CUSTOMREQUEST => 'POST',
			  CURLOPT_POSTFIELDS => array('app_id' => $this->widget_id,'authentication_key' => $this->api_key,'mobile_no' => $phone,'amount' => $total,'user_name' => $phone,'user_password' => $otpphone),
			//  CURLOPT_POSTFIELDS => array('app_id' => 'Woocommerce','authentication_key' => '8aa0f7a2-1767-40c2-9911-36875c47017c','mobile_no' => $phone,'amount' => '1','user_name' =>  $phone,'user_password' =>  $password),
			  CURLOPT_HTTPHEADER => array(
			//	'Content-Type: application/x-www-form-urlencoded',
				'x-api-key: ' . $this->api_key,
				'authentication-token: ' . $tokenupdate
				//'Cookie: ci_session=o4bv10dmvtdf1fpbokpbm3g8bknlt1u0'
			  ),
			));
			
		//	$responseotp = curl_exec($curlotp);
			$responseotp = json_decode(curl_exec($curlotp));
			curl_close($curlotp);
			
			

			if($responseotp->status==true){
				// Remove cart.

				wc_add_notice( $responseotp->message, 'error' );
			
				
			}
			else{ 

	
			wc_add_notice( $responseotp->status, 'error' );
			
		   
			}

		}





}			


		if($response->status==403){
			// Remove cart.
			
			wc_add_notice( $response->status, 'error' );
			
		}
	




		if($response->subcode=='10001'){
			// Remove cart.
			WC()->cart->empty_cart();
			update_post_meta($order_id, 'invoice_number', esc_html(sanitize_text_field($response->invoice_no)));
			$orderNote = __("Bykea Cash invoice is successfully created. Invoice number is <a href='https://invoice.bykea.cash/receive/invoice/".$response->invoice_no."' target='_blank'>".$response->invoice_no."</a>");
			$order->add_order_note( $orderNote );
			// Redirect to Bykea Cash redirect.
			return array(
				'result'   => 'success',
				'redirect' => $response->invoice_url,
			);
		}
		else{
			if($response->messages){
				foreach($response->messages as $key => $value){
					wc_add_notice( $value[0], 'error' );
				}
			}elseif($response->message){
				//wc_add_notice( $response->status, 'error' );
				//wc_add_notice( $response->refresh_token, 'error' );
				//wc_add_notice( $response->message, 'error' );


			}elseif($response->data->error){
				wc_add_notice( $response->data->error, 'error' );
			}else{
			wc_add_notice( $response->status, 'error' );
				wc_add_notice( $response->refresh_token, 'error' );
			wc_add_notice( $response->message, 'error' );
				wc_add_notice( 'There is some error in the payment option. Please try again later or choose another payment option.', 'error' );
			}
			return;
		}
		// if($response->subcode=='10001'){
		// 	// Remove cart.
		// 	WC()->cart->empty_cart();
		// 	update_post_meta($order_id, 'invoice_number', esc_html(sanitize_text_field($response->invoice_no)));
		// 	$orderNote = __("Bykea Cash invoice is successfully created. Invoice number is <a href='https://invoice.bykea.cash/receive/invoice/".$response->invoice_no."' target='_blank'>".$response->invoice_no."</a>");
		// 	$order->add_order_note( $orderNote );
		// 	// Redirect to Bykea Cash redirect.
		// 	return array(
		// 		'result'   => 'success',
		// 		'redirect' => $response->invoice_url,
		// 	);
		// }
		// else{
		// 	if($response->messages){
		// 		foreach($response->messages as $key => $value){
		// 			wc_add_notice( $value[0], 'error' );
		// 		}
		// 	}elseif($response->message){
		// 		wc_add_notice( $response->status, 'error' );
		// 		wc_add_notice( $response->refresh_token, 'error' );
		// 		wc_add_notice( $response->message, 'error' );


		// 	}elseif($response->data->error){
		// 		wc_add_notice( $response->data->error, 'error' );
		// 	}else{
		// 		wc_add_notice( 'There is some error in the payment option. Please try again later or choose another payment option.', 'error' );
		// 	}
		// 	return;
		// }

		// if ( is_wp_error( $response ) ) {
		// 	$error_message = $response->get_error_message();
		// 	return "Something went wrong: $error_message";
		// }

		// if ( 200 !== wp_remote_retrieve_response_code( $response ) ) {
		// 	$order->update_status( apply_filters( 'woocommerce_payleo_process_payment_order_status', $order->has_downloadable_item() ? 'wc-invoiced' : 'processing', $order ), __( 'Payments pending.', 'nupeye-payments-woo' ) );
		// }

		// if ( 200 === wp_remote_retrieve_response_code( $response ) ) {
		// 	$response_body = wp_remote_retrieve_body( $response );
		// 	var_dump($response_body['message']);
		// 	if ( 'Thank you! Your payment was successful' === $response_body['message'] ) {
		// 		$order->payment_complete();

		// 		// Remove cart.
		// 		WC()->cart->empty_cart();

		// 		// Return thankyou redirect.
		// 		return array(
		// 			'result'   => 'success',
		// 			'redirect' => $this->get_return_url( $order ),
		// 		);
		// 	}
		// }
	}
	
	
	/**
	 * Output for the order received page.
	 */
	public function thankyou_page() {
		if ( $this->instructions ) {
			echo wp_kses_post( wpautop( wptexturize( $this->instructions ) ) );
		}
	}

	/**
	 * Change payment complete order status to completed for payleo orders.
	 *
	 * @since  3.1.0
	 * @param  string         $status Current order status.
	 * @param  int            $order_id Order ID.
	 * @param  WC_Order|false $order Order object.
	 * @return string
	 */
	public function change_payment_complete_order_status( $status, $order_id = 0, $order = false ) {
		if ( $order && 'payleo' === $order->get_payment_method() ) {
			$status = 'completed';
		}
		return $status;
	}

	/**
	 * Add content to the WC emails.
	 *
	 * @param WC_Order $order Order object.
	 * @param bool     $sent_to_admin  Sent to admin.
	 * @param bool     $plain_text Email format: plain text or HTML.
	 */
	public function email_instructions( $order, $sent_to_admin, $plain_text = false ) {
		if ( $this->instructions && ! $sent_to_admin && $this->id === $order->get_payment_method() ) {
			echo wp_kses_post( wpautop( wptexturize( $this->instructions ) ) . PHP_EOL );
		}
	}
}